@@ -220,7 +220,10 @@ class ImageRecognition(object):
         return out, base_var_list
         
 
-    def batch_generator(self, batch_size, dataset_path, message):
+    def batch_generator(self, batch_size, 
+                            dataset_path, 
+                            message,
+                            randomly_cvt_grayscale=False):
         """Train Generator
         
         Arguments:
@@ -249,6 +252,9 @@ class ImageRecognition(object):
 
             for i in self.classes:
                 for j in range(perclass_sample):
+
+                    rand_num = random.randint(1, 4)
+
                     if idx[i] >= len(file_list_by_class[i]):
                         random.shuffle(file_list_by_class[i])
                         #print ("==>>> INFO: your " + message + " in class " + str(i) + " dataset is reshuffled again", idx[i])
@@ -271,6 +277,14 @@ class ImageRecognition(object):
                         x_batch.append(flip_tmp_x)
                         y_pred.append(tmp_y)
 
+                        if rand_num == 1: 
+                            gray_tmp_x = cv2.imread(dataset_path + i + "/" + file_list_by_class[i][idx[i]])
+                            gray_tmp_x = cv2.cvtColor(gray_tmp_x, cv2.COLOR_BGR2GRAY)
+                            gray_tmp_x = cv2.resize(gray_tmp_x, dsize=(self.input_width, self.input_height), interpolation=cv2.INTER_CUBIC)
+                            gray_tmp_x = gray_tmp_x.astype(np.float32) / 255.
+                            x_batch.append(gray_tmp_x)
+                            y_pred.append(tmp_y)
+
                     except Exception as e:
                         print ("-----------------------------------------------------------------------------")
                         print ('>>> WARNING: fail handling ' +  file_list_by_class[i][idx[i]], e)
